@@ -1,7 +1,7 @@
 
+class WhoIsQueryError(Exception):
+    pass
+
+
 class WhoIsParserError(Exception):
     pass
-
-
-class DomainValidationError(Exception):
-    pass
